#!/bin/bash

Summary: The default startup script for the X Window System.
Name: xinitrc
Version: 4.0.14
Release: 1
License: GPLv2, MIT/X11
Group: User Interface/X
Source: xinitrc-%{version}.tar.bz2
Buildroot: %{_tmppath}/%{name}-root
# FIXME: XFree86 dep has been disabled, because that causes the package to
# be dependant on a specific X11 implementation.  It isn't clear why this
# dependancy is here, so once we find out what breaks, we can add new
# dependancies here for them in a way that is not dependant on a specific
# implementation.  That can be done either by using file/dir dependancies,
# or by using virtual provides/requires.
# Mar 16, 2004 - mharris@redhat.com
#Requires: XFree86

# sessreg - is used by "GiveConsole" and "TakeConsole"
Requires: /usr/X11R6/bin/sessreg

# These are required by Xclients
Requires: which /usr/X11R6/bin/RunWM

# Xsetup_0 requires pidof and xsetroot
Requires: /sbin/pidof /usr/X11R6/bin/xsetroot

Requires: /bin/sh, /bin/bash, switchdesk >= 3.7
BuildArch: noarch

%description
The xinitrc package contains the xinitrc file, a script which is used
to configure your X Window System session or to start a window
manager.

%prep
%setup -q

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%config(noreplace) /etc/X11/Xmodmap
%config(noreplace) /etc/X11/Xresources
/etc/X11/xinit/xinitrc
/etc/X11/xinit/xinitrc-common
%config(noreplace) /etc/X11/xinit/Xclients
%dir /etc/X11/xinit/xinitrc.d
/etc/X11/xinit/xinitrc.d/*
%config(noreplace) /etc/X11/xdm/*
# FIXME: This should move to /usr/bin sometime, with a backward compatible
# symlink added back just prior to release, to help people to fix things to
# use /usr/bin instead.  Then keep the symlink for a release or so.  When
# this changes, X11BINDIR in the Makefile needs to be updated also.
/usr/X11R6/bin/RunWM

%changelog
* Wed Oct 20 2004 Mike A. Harris <mharris@redhat.com> 4.0.14-1
- Fix permissions on Xaccess file (#101065)
- Modified the way ssh-agent is invoked, which greatly simplified the
  xinitrc script, and removed the now unneeded SSH_AGENT variable (#134494)

* Wed Oct  6 2004 Mike A. Harris <mharris@redhat.com> 4.0.13-1
- Fix xinitrc script, by making it source xinitrc-common via absolute path
  instead of via relative path.  Same fix as was done for Xsession in build
  4.0.11-1 for bug (#134785)

* Wed Oct  6 2004 Mike A. Harris <mharris@redhat.com> 4.0.12-1
- Fix bug in ssh-agent support in Xsession which surfaced once common code
  was factored out into the xinitrc-common script.  Preston Brown's initial
  implementation of ssh-agent support used "SSHAGENT" in Xsession, but used
  "SSH_AGENT" in xinitrc.  The new common code uses "SSH_AGENT", however the
  Xsession script had some places remaining which still used "SSHAGENT",
  causing ssh-agent to fail to start.

* Wed Oct  6 2004 Mike A. Harris <mharris@redhat.com> 4.0.11-1
- Fix Xsession, by making it source xinitrc-common via absolute path
  instead of via relative path (#134785)

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com> 4.0.10-1
- Fix unterminated if block in the Xclients script, which was introduced in
  xinitrc-4.0.6-1 (#134673)

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com> 4.0.9-1
- Removed config flag from xinitrc script, as people should use xinitrc.d
  instead.
- Added xinitrc-common script to file list as it was missing in 4.0.8-1

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com> 4.0.8-1
- Factored out common code from Xsession and xinitrc into 'xinitrc-common'
  to avoid code duplication and bug fix synchronization issues (#133485)
- Changed default xsetroot background colour to "#222e45" (#134417)

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com> 4.0.7-1
- Fix dbus invocation to quit with X session, by adding --exit-with-session
  switch in Xsession and xinitrc. (#133557)
- Fix Xsession and xinitrc ssh-agent invocation to only start if ssh-agent
  is not already running (#90158)

* Tue Oct  5 2004 Mike A. Harris <mharris@redhat.com> 4.0.6-1
- Secondary wmakerectomy to prevent remission.

* Thu Sep 24 2004 Mike A. Harris <mharris@redhat.com> 4.0.5-1
- fvwm2ectomy, and netscapectomy (#123284)
- Remove all references to the XF86Config file from all scripts in the package,
  as these were all just ugly hacks, and all appear to be unneeded nowadays
  anyway.  (#133477)

* Wed Sep  1 2004 Mike A. Harris <mharris@redhat.com> 4.0.4-1
- fvwmectomy

* Wed Aug 25 2004 Colin Walters <walters@redhat.com> 4.0.3-1
- Add DBus session to Xsession, xinitrc

* Sat Aug 21 2004 Jens Petersen <petersen@redhat.com> 4.0.2-1
- bring back sourcing of lang.sh in xinput.sh so that it honours
  i18n locale settings (#127746)
- add support for all locale fallback script "default" in xinput.d directory

* Wed Jun 23 2004 Mike A. Harris <mharris@redhat.com> 4.0.1-1
- Added fix for switchdesk related bug in Xsession script (#125284)
- Integrated input.d modularization support implemented by Jens Petersen
  based upon idea from Akira Tagoh:
  - no need to source lang.sh
  - do not look at LC_ALL
  - initialize XIM, XIM_PROGRAM, XIM_ARGS, XMODIFIERS and GTK_IM_MODULE unset
    for consistency and safety
  - replace all specific locale and IM client config code with trying to
    load ~/.xinput.d/ll_CC, then /etc/X11/xinit/xinput.d/ll_CC
    (when they exist for ll_CC locale).  Each script is expected to set
    XIM_PROGRAM, XIM_ARGS, and either XIM or XMODIFIERS directly, and
    optionally GTK_IM_MODULE if appropriate.
  - export XMODIFIERS also if it was already initialized

* Wed Jun 23 2004 Mike A. Harris <mharris@redhat.com> 4.0.0-1
- Created xinitrc-3-stable-branch in CVS for maintaining the 3.x branch of
  xinitrc.  New development will occur in the 4.x releases, intended for
  Fedora Core 3 and Red Hat Enterprise Linux 4.
- Added back changes from 3.40-1 which were reverted in 3.42-1, as these were
  intended for development.
- Renamed xinput script to xinput.sh to comply with new *.sh policy of scripts
  in xinitrc.d directory
- Do not flag /etc/X11/xinit/xinitrc.d/* as config files, as they are scripts,
  not config files.

* Wed Jun 23 2004 Mike A. Harris <mharris@redhat.com> 3.42-1
- Reverted changes from 3.40-1, which were intended to be included in
  Fedora Core 3 development, but accidentally made it into Fedora Core 2
  erratum.

* Tue Jun  1 2004 Mike A. Harris <mharris@redhat.com> 3.41-1
- Fixed missing quote in xinput script (#123804)

* Fri May  7 2004 Mike A. Harris <mharris@redhat.com> 3.40-1
- Modified xinitrc and Xsession scripts to only source files with .sh
  extensions in /etc/X11/xinit/xinitrc.d/* so that backup files that are
  created when hand editing the scripts, aren't executed. (FC2BLOCKER
  #119241)

* Tue Mar 30 2004 Mike A. Harris <mharris@redhat.com> 3.39-1
- Fix problem in xinput script caused due to a bit of over-quoting in recent
  changes, which result in logged erros (FC2 BLOCKER #119529)

* Mon Mar 29 2004 Mike A. Harris <mharris@redhat.com> 3.38-1
- xinput fixes:
  - Fix missing ']' on elif test on line 25 (FC2 BLOCKER #119284)
  - Change test for /etc/profile.d/lang.sh to test with -r instead of -f
  - Change all non-null string tests to use -n instead of != ""
  - Change broken test logic in KDE block to use -o instead of ||
  - Fixes for iiimf getting turned on even for European languages where it
    is not useful. (Jens Petersen, FC2 BLOCKER #119240)
- Xsession cleanups:
  - Update Xsession for new switchdesk (Than Ngo, FC2 BLOCKER #116164)
  - Change all file existance tests using -f, to -r since we care if it is
    readable rather than if it exists or not.
  - Use new style $() command substitution rather than ``
- Updated the copyright messages of all script files, and added missing
  GPLv2 notices where appropriate.  Updated License: tag of spec file to be
  "GPLv2, MIT/X11"

* Tue Mar 16 2004 Mike A. Harris <mharris@redhat.com> 3.37-1
- Disable Requires: XFree86 dep, and add comment to spec file with reasoning,
  so if anything breaks, we can fix it up in a better way later on
- Xclients cleanups:
  - Check for existance of xclock and xterm binaries, both in /usr/bin, and
    in /usr/X11R6/bin before trying to execute either in failsafe
  - Check for executable existance of mozilla/fvwm/twm with -x, rather than
    just checking for existance with -f, and then use the explicit path to
    these binaries when executing them
- xinput cleanups:
  - Change shebang to use /bin/bash instead of /bin/sh, as our OS is always
    guaranteed to have /bin/bash installed on it because many other things
    require it anyway.  This makes it explicitly legal to use bashisms
    everywhere, of which are usually already being used anyway without notice,
    because /bin/sh is a link to /bin/bash by default.
  - Replace old style usage of "test x$foo" with 'if [ "$foo"' as it is much
    more readable.
  - Test for the readability of /etc/sysconfig/i18n with -r, rather than
    it's mere existance with -e
  - Everywhere -e was used to test for the existance of a binary prior to
    executing it, has been replaced with -x, which tests for executability
- Added "Requires: /usr/X11R6/bin/sessreg" for GiveConsole and TakeConsole
- Added "Requires: which /usr/X11R6/bin/RunWM" for Xclients
- Added "Requires: /sbin/pidof /usr/X11R6/bin/xsetroot" for Xsetup_0

* Tue Mar 16 2004 Jens Petersen <petersen@redhat.com> 3.36-1
- default input method to htt (im-iiim for gtk apps and httx for xim apps)
  if htt is running when XIM is not set (#118382)
- default kinput2 to use canna if cannaserver running or wnn if jserver
  running (Adrian Havill, #112631) when XIM_ARGS is not set 
- add support for nabi (sangu, #112521) and uim
- do not set XIM to none (Eric Backus, #57876)
- ami no longer includes applet (Won-kyu Park, #61540) and so delayed-start
  code is no longer needed

* Thu Oct 23 2003 Mike A. Harris <mharris@redhat.com> 3.35-1
- Remove limitations forcing xcin to only work in UTF-8 mode (#97331)

* Mon Oct 20 2003 Mike A. Harris <mharris@redhat.com> 3.34-1
- Changed the default background colour argument passed to xsetroot in both
  the Xsession and Xsetup_0 scripts from "#5477A0" to "#20305A"

* Thu Aug 28 2003 Mike A. Harris <mharris@redhat.com> 3.33-1
- Added Xsession update for new gdm for Cambridge (#103251)

* Wed Feb  5 2003 Mike A. Harris <mharris@redhat.com> 3.32-1
- Rebuild

* Tue Sep 10 2002 Bill Nottingham <notting@redhat.com> 3.30-1
- unset TERM to avoid font wackiness when sourcing lang.sh

* Thu Sep  5 2002 Owen Taylor <otaylor@redhat.com> 3.29-1
- Add . /etc/profile.d/lang.sh to xinput (#73062)

* Mon Sep  2 2002 Owen Taylor <otaylor@redhat.com> 3.28-1
- Change default Xft hinting settings to hintmedium, not hintnone

* Wed Aug 28 2002 Bill Nottingham <notting@redhat.com> 3.27-1
- don't grep /etc/sysconfig/desktop; actually read it

* Wed Jul 31 2002 Mike A. Harris <mharris@redhat.com> 3.26-1
- Added windowmaker support to Xclients for bug (#66225)

* Sat Jul 20 2002 Mike A. Harris <mharris@redhat.com> 3.25-1
- Fix ssh-agent code added on Jun 27th to not start ssh-agent if it is
  already running (#68626)

* Fri Jun 28 2002 Owen Taylor <otaylor@redhat.com> 3.24-1
- Add a Xresources file that sets Xft DPI to 96
- Make Xsetup_0 load /etc/X11/Xresources

* Thu Jun 27 2002 Preston Brown <pbrown@redhat.com> 3.23-1
- use ssh-agent to start sessions if available.

* Mon Apr  8 2002 Mike A. Harris <mharris@redhat.com> 3.22-1
- There were 3 different versions of 3.21 from different developers, which
  had reverted some of my previous changes.  I believe I have now fixed
  these problems.
- Added Wnn7 support from Yukihiro Nakai <ynakai@redhat.com> (#61951)
- Made changes for Leon (removed debugging code from xinput, etc)

* Wed Feb 27 2002 Mike A. Harris <mharris@redhat.com> 3.21-1
- Removed glidelink hack, as XFree86 4.2.0 now comes with code to load
  the proper glide3 library automatically.

* Thu Aug 23 2001 Mike A. Harris <mharris@redhat.com> 3.20-1
- Removed tempfile vulnerability in xinput writing to /tmp/start.txt
  (MF #52304)

* Tue Aug 21 2001 Leon Ho <llch@redhat.com> 3.19-1
- covers all track from Xclient (ie. gdm to kde, kdm to gnome etc)
- covers if $LANG not exist on this scope yet
- Modified Korean part to work on both gnome and kde

* Thu Aug  9 2001 Yukihiro Nakai <ynakai@redhat.com> 3.17-1
- Improve Korean support.
- skkinput support.

* Wed Aug  8 2001 Crutcher Dunnavant <crutcher@redhat.com> 3.16-1
- make selection of Xclient smarter

* Fri Aug  3 2001 Owen Taylor <otaylor@redhat.com>
- Change background color a bit, only run xsri if not running under gdm,
  since our gdm config will run it itself.
- Change background for Xsession as well

* Mon Jul 30 2001 Mike A. Harris <mharris@redhat.com> 3.13-1
- Removed '-login' from Xsession script, and changed exec calls to the
  form 'exec -l $SHELL -c foo' as discussed with Havoc.
- Added explicit requires on /bin/bash

* Mon Jul 16 2001 Mike A. Harris <mharris@redhat.com> 3.12-1
- Pure hack: Have xinitrc symlink the glide lib using glidelink to fix (#36158)
  and numerous other duplicates.  Temporary solution until XFree86 4.2.0 is
  released.
- xinitrc tested for Netscape and fvwm2 presence with -f instead of -x

* Sun Jul  8 2001 Yukihiro Nakai <ynakai@redhat.com>
- Add miniChinput entry to xinput.
- Fix the xcin entry for zh_CN.GB2312

* Sun May 06 2001 Than Ngo <than@redhat.com>
- fixed tmpfile vulnerability (Bug #39083)

* Mon Mar 26 2001 Preston Brown <pbrown@redhat.com>
- remove references to afterstep (#32877)

* Fri Mar 16 2001 Yukihiro Nakai <ynakai@redhat.com>
- Update xinput to enable Omron's Wnn6

* Thu Feb 08 2001 Yukihiro Nakai <ynakai@redhat.com>
- More fix for kinput2 + FreeWnn

* Tue Jan 23 2001 Than Ngo <than@redhat.com>
- changed /bin/sh in Xsession to /bin/bash -login

* Fri Jan 12 2001 Yukihiro Nakai <ynakai@redhat.com>
- More improvement for Korean and Japanese

* Wed Jan 10 2001 Yukihiro Nakai <ynakai@redhat.com>
- Change ko_KR* -> ko*

* Tue Dec 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add xdm-config (used to be in XFree86-xdm)

* Thu Dec 14 2000 Yukihiro Nakai <ynakai@redhat.com>
- Add zh_TW, and fix

* Wed Dec 06 2000 Yukihiro Nakai <ynakai@redhat.com>
- Add Japanese fix. Use -canna option for kinput2.
- Add Korean and Chinese support.

* Thu Nov 16 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- adapt to KDE 2.0 (Bug #20409)
- require switchdesk >= 3.7 rather than 3.6 (KDE2)
- The fallback should launch netscape /usr/share/doc/HTML/index.html
  rather than /usr/doc/HTML/index.html...
- bzip2 the source rather than gzipping it

* Wed Oct 11 2000 Than Ngo <than@redhat.com>
- fix Xsetup_0 (Bug #17873)

* Wed Sep 13 2000 Matt Wilson <msw@redhat.com>
- make Xsession start a -login shell

* Wed Sep 06 2000 Preston Brown <pbrown@redhat.com>
- remove references to anotherlevel

* Tue Aug 22 2000 Than Ngo <than@redhat.com>
- add KDE2 support

* Sun Aug 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- add /usr/X11R6/bin to the PATH if it's not in there already (#16648)
- don't call cp in a subshell when trying to create a log file

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- more files move in

* Fri Jul 14 2000 Preston Brown <pbrown@redhat.com>
- more wmaker path fixage

* Tue Jul 11 2000 Trond Eivind Glomsrd <teg@redhat.com>
- wmaker is now in /usr/bin

* Thu Jun 22 2000 Bill Nottingham <notting@redhat.com>
- import some of the xdm stuff here, it's used by both xdm and gdm

* Fri Jun 16 2000 Matt Wilson <msw@redhat.com>
- import these files into our CVS server

* Tue May 30 2000 Preston Brown <pbrown@redhat.com>
- commented out mappings in global Xmodmap.  Caused problems with many
  remote logins from various X devices besides Linux boxes.

* Tue Mar 14 2000 Matt Wilson <msw@redhat.com>
- export XMODIFIERS for japanese

* Fri Mar 03 2000 Cristian Gafton <gafton@redhat.com>
- fix windowmaker default initialization (use wmaker.inst for the
  first start of WindowMaker)

* Mon Feb 28 2000 Preston Brown <pbrown@redhat.com>
- process /etc/X11/XF86Config file with the sed script for xkb.

* Mon Feb 21 2000 Preston Brown <pbrown@redhat.com>
- quote shell variables in xinitrc (#9547)

* Thu Feb 10 2000 Preston Brown <pbrown@redhat.com>
- change /usr/X11R6/lib/X11 /etc/X11 for some config files.

* Thu Feb 10 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix a typo

* Tue Feb  8 2000 Bill Nottingham <notting@redhat.com>
- fix two syntax errors

* Tue Jan 11 2000 Preston Brown <pbrown@redhat.com>
- added support for scripts a la /etc/profile.d in /etc/X11/xinit/xinitrc.d.
- moved japanese xinput stuff into an xinitrc.d script
- cleaned up duplicate runs of xmodmap (#7839).
- noreplace tag added for most config files.

* Wed Oct 20 1999 Matt Wilson <msw@redhat.com>
- added patch from Owen to start kinput2 by default for all desktops when
  running under Japanese

* Mon Oct 18 1999 Preston Brown <pbrown@redhat.com>
- patched xinitrc to run setxkbmap -symbols on sparc if XkbSymbols variable
  is defined (from Jakub)

* Thu Sep 23 1999 Preston Brown <pbrown@redhat.com>
- enable use of xkb configuration files if they are present (# 4059)

* Thu Jun 17 1999 Bill Nottingham <notting@redhat.com>
- make Xclients/xinitrc executable...

* Thu Jun 10 1999 Preston Brown <pbrown@redhat.com>
- look for not only .Xmodmap/.Xresources, but also Xmodmap/Xresources
- Xmodmap w/ "keycode 22 = BackSpace" added for non Xkb-extension users

* Mon Apr 19 1999 Preston Brown <pbrown@redhat.com>
- argh, fixed my changes from yesterday

* Sun Apr 18 1999 Preston Brown <pbrown@redhat.com>
- added /etc/sysconfig/desktop support

* Mon Mar 22 1999 Bill Nottingham <notting@redhat.com>
- make /etc/X11/xinit/* %config (bug #1051)

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Tue Feb 02 1999 Preston Brown <pbrown@redhat.com>
- added ability to have KDE recognized if it is all that is installed

* Wed Jan 27 1999 Preston Brown <pbrown@redhat.com>
- updated so that GNOME is the default, and a few other cleanups

* Fri Sep 18 1998 Cristian Gafton <gafton@redhat.com>
- added the RunWM script and modified Xclients to use this new script

* Sun Sep 13 1998 Cristian Gafton <gafton@redhat.com>
- included WindowMaker hints

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed Apr 22 1998 Cristian Gafton <gafton@redhat.com>
- handle AfterStep (and possibly other window managers)

* Tue Nov 11 1997 Michael K. Johnson <johnsonm@redhat.com>
- export the BROWSER variable.

* Fri Nov 08 1997 Cristian Gafton <gafton@redhat.com>
- added handling for the BROWSER variable

* Wed Oct 15 1997 Cristian Gaftin <gafton@redhat.com>
- updated for AnotherLevel

* Fri Jul 18 1997 Erik Troan <ewt@redhat.com>
- built for glibc, added dependencies

* Thu Mar 20 1997 Erik Troan <ewt@redhat.com>
- Added /etc/X11/xinitrc/Xclients to this file and removed it from rootfiles
  and etcskel.

